from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelInferResponse(_message.Message):
    __slots__ = ("model_name", "model_version", "id", "parameters", "outputs", "raw_output_contents")
    class InferOutputTensor(_message.Message):
        __slots__ = ("name", "datatype", "shape", "parameters", "contents")
        class ParametersEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: InferParameter
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[InferParameter, _Mapping]] = ...) -> None: ...
        NAME_FIELD_NUMBER: _ClassVar[int]
        DATATYPE_FIELD_NUMBER: _ClassVar[int]
        SHAPE_FIELD_NUMBER: _ClassVar[int]
        PARAMETERS_FIELD_NUMBER: _ClassVar[int]
        CONTENTS_FIELD_NUMBER: _ClassVar[int]
        name: str
        datatype: str
        shape: _containers.RepeatedScalarFieldContainer[int]
        parameters: _containers.MessageMap[str, InferParameter]
        contents: InferTensorContents
        def __init__(self, name: _Optional[str] = ..., datatype: _Optional[str] = ..., shape: _Optional[_Iterable[int]] = ..., parameters: _Optional[_Mapping[str, InferParameter]] = ..., contents: _Optional[_Union[InferTensorContents, _Mapping]] = ...) -> None: ...
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: InferParameter
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[InferParameter, _Mapping]] = ...) -> None: ...
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    RAW_OUTPUT_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    model_name: str
    model_version: str
    id: str
    parameters: _containers.MessageMap[str, InferParameter]
    outputs: _containers.RepeatedCompositeFieldContainer[ModelInferResponse.InferOutputTensor]
    raw_output_contents: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, model_name: _Optional[str] = ..., model_version: _Optional[str] = ..., id: _Optional[str] = ..., parameters: _Optional[_Mapping[str, InferParameter]] = ..., outputs: _Optional[_Iterable[_Union[ModelInferResponse.InferOutputTensor, _Mapping]]] = ..., raw_output_contents: _Optional[_Iterable[bytes]] = ...) -> None: ...

class InferParameter(_message.Message):
    __slots__ = ("bool_param", "int64_param", "string_param", "double_param", "uint64_param")
    BOOL_PARAM_FIELD_NUMBER: _ClassVar[int]
    INT64_PARAM_FIELD_NUMBER: _ClassVar[int]
    STRING_PARAM_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_PARAM_FIELD_NUMBER: _ClassVar[int]
    UINT64_PARAM_FIELD_NUMBER: _ClassVar[int]
    bool_param: bool
    int64_param: int
    string_param: str
    double_param: float
    uint64_param: int
    def __init__(self, bool_param: bool = ..., int64_param: _Optional[int] = ..., string_param: _Optional[str] = ..., double_param: _Optional[float] = ..., uint64_param: _Optional[int] = ...) -> None: ...

class InferTensorContents(_message.Message):
    __slots__ = ("bool_contents", "int_contents", "int64_contents", "uint_contents", "uint64_contents", "fp32_contents", "fp64_contents", "bytes_contents")
    BOOL_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    INT_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    INT64_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    UINT_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    UINT64_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    FP32_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    FP64_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    BYTES_CONTENTS_FIELD_NUMBER: _ClassVar[int]
    bool_contents: _containers.RepeatedScalarFieldContainer[bool]
    int_contents: _containers.RepeatedScalarFieldContainer[int]
    int64_contents: _containers.RepeatedScalarFieldContainer[int]
    uint_contents: _containers.RepeatedScalarFieldContainer[int]
    uint64_contents: _containers.RepeatedScalarFieldContainer[int]
    fp32_contents: _containers.RepeatedScalarFieldContainer[float]
    fp64_contents: _containers.RepeatedScalarFieldContainer[float]
    bytes_contents: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, bool_contents: _Optional[_Iterable[bool]] = ..., int_contents: _Optional[_Iterable[int]] = ..., int64_contents: _Optional[_Iterable[int]] = ..., uint_contents: _Optional[_Iterable[int]] = ..., uint64_contents: _Optional[_Iterable[int]] = ..., fp32_contents: _Optional[_Iterable[float]] = ..., fp64_contents: _Optional[_Iterable[float]] = ..., bytes_contents: _Optional[_Iterable[bytes]] = ...) -> None: ...



from apis.inference.v1 import open_inference_pb2 as _open_inference_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InferImageRequest(_message.Message):
    __slots__ = ("model_name", "model_version", "id", "image", "image_url", "option")
    class ImageScale(_message.Message):
        __slots__ = ("image_height", "image_width", "max_image_size", "image_size_unit")
        IMAGE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
        IMAGE_WIDTH_FIELD_NUMBER: _ClassVar[int]
        MAX_IMAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
        IMAGE_SIZE_UNIT_FIELD_NUMBER: _ClassVar[int]
        image_height: int
        image_width: int
        max_image_size: int
        image_size_unit: int
        def __init__(self, image_height: _Optional[int] = ..., image_width: _Optional[int] = ..., max_image_size: _Optional[int] = ..., image_size_unit: _Optional[int] = ...) -> None: ...
    class InferImageOption(_message.Message):
        __slots__ = ("scale", "use_cv2_color", "normalization")
        SCALE_FIELD_NUMBER: _ClassVar[int]
        USE_CV2_COLOR_FIELD_NUMBER: _ClassVar[int]
        NORMALIZATION_FIELD_NUMBER: _ClassVar[int]
        scale: InferImageRequest.ImageScale
        use_cv2_color: bool
        normalization: bool
        def __init__(self, scale: _Optional[_Union[InferImageRequest.ImageScale, _Mapping]] = ..., use_cv2_color: bool = ..., normalization: bool = ...) -> None: ...
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    model_name: str
    model_version: str
    id: str
    image: bytes
    image_url: str
    option: InferImageRequest.InferImageOption
    def __init__(self, model_name: _Optional[str] = ..., model_version: _Optional[str] = ..., id: _Optional[str] = ..., image: _Optional[bytes] = ..., image_url: _Optional[str] = ..., option: _Optional[_Union[InferImageRequest.InferImageOption, _Mapping]] = ...) -> None: ...

class InferImageResponse(_message.Message):
    __slots__ = ("model_response", "input_image_height", "input_image_width")
    MODEL_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    INPUT_IMAGE_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INPUT_IMAGE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    model_response: _open_inference_pb2.ModelInferResponse
    input_image_height: int
    input_image_width: int
    def __init__(self, model_response: _Optional[_Union[_open_inference_pb2.ModelInferResponse, _Mapping]] = ..., input_image_height: _Optional[int] = ..., input_image_width: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/infer.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apis.inference.v1 import image_pb2 as apis_dot_inference_dot_v1_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pis/inference/v1/infer.proto\x12\x0cinference.v1\x1a\x1d\x61pis/inference/v1/image.protoBo\n\x10\x63om.inference.v1B\nInferProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.infer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\nInferProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from apis.inference.v1 import image_pb2 as apis_dot_inference_dot_v1_dot_image__pb2


class ImageInferenceServiceStub(object):
    """Inference Server GRPC endpoints for images.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InferImage = channel.unary_unary(
                '/inference.v1.ImageInferenceService/InferImage',
                request_serializer=apis_dot_inference_dot_v1_dot_image__pb2.InferImageRequest.SerializeToString,
                response_deserializer=apis_dot_inference_dot_v1_dot_image__pb2.InferImageResponse.FromString,
                )


class ImageInferenceServiceServicer(object):
    """Inference Server GRPC endpoints for images.
    """

    def InferImage(self, request, context):
        """The InferImage API performs inference using the specified model for one image. Errors are
        indicated by the google.rpc.Status returned for the request. The OK code 
        indicates success and other codes indicate failure.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageInferenceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InferImage': grpc.unary_unary_rpc_method_handler(
                    servicer.InferImage,
                    request_deserializer=apis_dot_inference_dot_v1_dot_image__pb2.InferImageRequest.FromString,
                    response_serializer=apis_dot_inference_dot_v1_dot_image__pb2.InferImageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'inference.v1.ImageInferenceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageInferenceService(object):
    """Inference Server GRPC endpoints for images.
    """

    @staticmethod
    def InferImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/inference.v1.ImageInferenceService/InferImage',
            apis_dot_inference_dot_v1_dot_image__pb2.InferImageRequest.SerializeToString,
            apis_dot_inference_dot_v1_dot_image__pb2.InferImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/image.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from apis.inference.v1 import open_inference_pb2 as apis_dot_inference_dot_v1_dot_open__inference__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pis/inference/v1/image.proto\x12\x0cinference.v1\x1a&apis/inference/v1/open_inference.proto\"\xa6\x04\n\x11InferImageRequest\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12#\n\rmodel_version\x18\x02 \x01(\tR\x0cmodelVersion\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12\x14\n\x05image\x18\x04 \x01(\x0cR\x05image\x12\x1b\n\timage_url\x18\x05 \x01(\tR\x08imageUrl\x12H\n\x06option\x18\x06 \x01(\x0b\x32\x30.inference.v1.InferImageRequest.InferImageOptionR\x06option\x1a\x9e\x01\n\nImageScale\x12!\n\x0cimage_height\x18\x01 \x01(\x05R\x0bimageHeight\x12\x1f\n\x0bimage_width\x18\x02 \x01(\x05R\nimageWidth\x12$\n\x0emax_image_size\x18\x03 \x01(\x05R\x0cmaxImageSize\x12&\n\x0fimage_size_unit\x18\x04 \x01(\x05R\rimageSizeUnit\x1a\x9e\x01\n\x10InferImageOption\x12@\n\x05scale\x18\x01 \x01(\x0b\x32*.inference.v1.InferImageRequest.ImageScaleR\x05scale\x12\"\n\ruse_cv2_color\x18\x02 \x01(\x08R\x0buseCv2Color\x12$\n\rnormalization\x18\x03 \x01(\x08R\rnormalization\"\xb7\x01\n\x12InferImageResponse\x12G\n\x0emodel_response\x18\x01 \x01(\x0b\x32 .inference.v1.ModelInferResponseR\rmodelResponse\x12,\n\x12input_image_height\x18\x02 \x01(\x05R\x10inputImageHeight\x12*\n\x11input_image_width\x18\x03 \x01(\x05R\x0finputImageWidth2j\n\x15ImageInferenceService\x12Q\n\nInferImage\x12\x1f.inference.v1.InferImageRequest\x1a .inference.v1.InferImageResponse\"\x00\x42o\n\x10\x63om.inference.v1B\nImageProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\nImageProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
  _globals['_INFERIMAGEREQUEST']._serialized_start=88
  _globals['_INFERIMAGEREQUEST']._serialized_end=638
  _globals['_INFERIMAGEREQUEST_IMAGESCALE']._serialized_start=319
  _globals['_INFERIMAGEREQUEST_IMAGESCALE']._serialized_end=477
  _globals['_INFERIMAGEREQUEST_INFERIMAGEOPTION']._serialized_start=480
  _globals['_INFERIMAGEREQUEST_INFERIMAGEOPTION']._serialized_end=638
  _globals['_INFERIMAGERESPONSE']._serialized_start=641
  _globals['_INFERIMAGERESPONSE']._serialized_end=824
  _globals['_IMAGEINFERENCESERVICE']._serialized_start=826
  _globals['_IMAGEINFERENCESERVICE']._serialized_end=932
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: apis/inference/v1/open_inference.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&apis/inference/v1/open_inference.proto\x12\x0cinference.v1\"\xf1\x05\n\x12ModelInferResponse\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12#\n\rmodel_version\x18\x02 \x01(\tR\x0cmodelVersion\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12P\n\nparameters\x18\x04 \x03(\x0b\x32\x30.inference.v1.ModelInferResponse.ParametersEntryR\nparameters\x12L\n\x07outputs\x18\x05 \x03(\x0b\x32\x32.inference.v1.ModelInferResponse.InferOutputTensorR\x07outputs\x12.\n\x13raw_output_contents\x18\x06 \x03(\x0cR\x11rawOutputContents\x1a\xd9\x02\n\x11InferOutputTensor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08\x64\x61tatype\x18\x02 \x01(\tR\x08\x64\x61tatype\x12\x14\n\x05shape\x18\x03 \x03(\x03R\x05shape\x12\x62\n\nparameters\x18\x04 \x03(\x0b\x32\x42.inference.v1.ModelInferResponse.InferOutputTensor.ParametersEntryR\nparameters\x12=\n\x08\x63ontents\x18\x05 \x01(\x0b\x32!.inference.v1.InferTensorContentsR\x08\x63ontents\x1a[\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.inference.v1.InferParameterR\x05value:\x02\x38\x01\x1a[\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.inference.v1.InferParameterR\x05value:\x02\x38\x01\"\xd7\x01\n\x0eInferParameter\x12\x1f\n\nbool_param\x18\x01 \x01(\x08H\x00R\tboolParam\x12!\n\x0bint64_param\x18\x02 \x01(\x03H\x00R\nint64Param\x12#\n\x0cstring_param\x18\x03 \x01(\tH\x00R\x0bstringParam\x12#\n\x0c\x64ouble_param\x18\x04 \x01(\x01H\x00R\x0b\x64oubleParam\x12#\n\x0cuint64_param\x18\x05 \x01(\x04H\x00R\x0buint64ParamB\x12\n\x10parameter_choice\"\xc3\x02\n\x13InferTensorContents\x12#\n\rbool_contents\x18\x01 \x03(\x08R\x0c\x62oolContents\x12!\n\x0cint_contents\x18\x02 \x03(\x05R\x0bintContents\x12%\n\x0eint64_contents\x18\x03 \x03(\x03R\rint64Contents\x12#\n\ruint_contents\x18\x04 \x03(\rR\x0cuintContents\x12\'\n\x0fuint64_contents\x18\x05 \x03(\x04R\x0euint64Contents\x12#\n\rfp32_contents\x18\x06 \x03(\x02R\x0c\x66p32Contents\x12#\n\rfp64_contents\x18\x07 \x03(\x01R\x0c\x66p64Contents\x12%\n\x0e\x62ytes_contents\x18\x08 \x03(\x0cR\rbytesContentsBw\n\x10\x63om.inference.v1B\x12OpenInferenceProtoP\x01\xa2\x02\x03IXX\xaa\x02\x0cInference.V1\xca\x02\x0cInference\\V1\xe2\x02\x18Inference\\V1\\GPBMetadata\xea\x02\rInference::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apis.inference.v1.open_inference_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.inference.v1B\022OpenInferenceProtoP\001\242\002\003IXX\252\002\014Inference.V1\312\002\014Inference\\V1\342\002\030Inference\\V1\\GPBMetadata\352\002\rInference::V1'
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._options = None
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._options = None
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_MODELINFERRESPONSE']._serialized_start=57
  _globals['_MODELINFERRESPONSE']._serialized_end=810
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR']._serialized_start=372
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR']._serialized_end=717
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_start=626
  _globals['_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY']._serialized_end=717
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_start=626
  _globals['_MODELINFERRESPONSE_PARAMETERSENTRY']._serialized_end=717
  _globals['_INFERPARAMETER']._serialized_start=813
  _globals['_INFERPARAMETER']._serialized_end=1028
  _globals['_INFERTENSORCONTENTS']._serialized_start=1031
  _globals['_INFERTENSORCONTENTS']._serialized_end=1354
# @@protoc_insertion_point(module_scope)
